<?php

namespace Drupal\locale_override;

use Drupal\Core\Cache\Cache;
use Drupal\Core\StringTranslation\Translator\StaticTranslation;

/**
 * Provides locale (string) overrides.
 */
class LocaleOverrideTranslation extends StaticTranslation {

  /**
   * {@inheritdoc}
   */
  protected function getLanguage($langcode) {
    $cid = 'locale_overrides:strings.' . $langcode;
    if ($cache = \Drupal::cache()->get($cid)) {
      return $cache->data;
    }
    else {
      $translations = [];
      $strings = \Drupal::config('locale_override.settings')->get('strings') ?: [];
      foreach ($strings as $string) {
        if ($string['source'] !== $string['translation']) {
          $translations[$string['context']][$string['source']] = $string['translation'];
        }
      }
      \Drupal::cache()->set($cid, $translations, Cache::PERMANENT, ['local_override']);
      return $translations;
    }
  }

}
